@@ -1,6 +1,7 @@
 mergeTrackObs<-function (sppdfInt, sppdfObs, obscol=NULL) {
-  trc <- coordinates(sppdfInt)
-  obs <- coordinates(sppdfObs)
+  if (st_crs(sppdfInt) != st_crs(sppdfObs)) stop("coordinate reference system must be identical")
+  trc <- st_coordinates(sppdfInt)
+  obs <- st_coordinates(sppdfObs)
   trckObs <- data.frame(trc, nObs = 0)
   for (i in 1:nrow(obs)) {
     distCal<-data.frame(matrix(rep(obs[i,],nrow(trc)),ncol=2,byrow=T),trc)
@@ -8,10 +9,10 @@ mergeTrackObs<-function (sppdfInt, sppdfObs, obscol=NULL) {
     idxtrc<-which(distCal$dist==min(distCal$dist))[1]
     if (is.null(obscol)){
       trckObs$nObs[idxtrc]<-trckObs$nObs[idxtrc]+1
-    } else trckObs$nObs[idxtrc]<-trckObs$nObs[idxtrc]+sppdfObs@data[i,obscol]
+    } else trckObs$nObs[idxtrc]<-trckObs$nObs[idxtrc]+st_drop_geometry(sppdfObs)[i,obscol]
   }
   trckObs <- data.frame(ID = 1:nrow(trckObs), trckObs)
-  names(trckObs)[2:3] <- c("x", "y")
-  coordinates(trckObs) <- ~x + y
-  trckObs
+  st_as_sf(trckObs,coords=c("X","Y"),crs=st_crs(sppdfObs))
 }
+
+
